OC.L10N.register(
    "core",
    {
    "Please select a file." : "Hãy chọn một tệp.",
    "File is too big" : "Tệp quá lớn",
    "The selected file is not an image." : "Tệp tin được chọn không phải là ảnh.",
    "The selected file cannot be read." : "Tệp tin được chọn không thể đọc.",
    "The file was uploaded" : "Tập tin đã được tải lên",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Tập tin tải lên đã vượt quá upload_max_filesize giới hạn trong hệ thống",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Tập được tải lên vượt quá MAX_FILE_SIZE đã được giới hạn trong biểu mẫu HTML",
    "The file was only partially uploaded" : "Tệp chỉ được tải lên một phần",
    "No file was uploaded" : "Chưa có tệp nào dược tải lên",
    "Missing a temporary folder" : "Thiếu một thư mục tạm thời",
    "Could not write file to disk" : "Không thể ghi tệp lên ổ đĩa",
    "A PHP extension stopped the file upload" : "Một phần mở rộng của PHP đã dừng tải tệp lên",
    "Invalid file provided" : "File không hợp lệ",
    "No image or file provided" : "Không có hình ảnh hoặc tập tin được cung cấp",
    "Unknown filetype" : "Không biết kiểu tập tin",
    "An error occurred. Please contact your admin." : "Có lỗi xảy ra. Vui lòng báo cho quản trị viên.",
    "Invalid image" : "Hình ảnh không hợp lệ",
    "No temporary profile picture available, try again" : "Ảnh cá nhân tạm thời không có giá trị, hãy thử lại",
    "No crop data provided" : "Không có dữ liệu nguồn được cung cấp",
    "No valid crop data provided" : "Dữ liệu trích xuất không hợp lệ",
    "Crop is not square" : "Trích xuất không chuẩn",
    "State token does not match" : "Mã trạng thái không khớp",
    "Invalid app password" : "Mật khẩu ứng dụng không hợp lệ",
    "Could not complete login" : "Không thể hoàn thành đăng nhập",
    "Login" : "Đăng nhập",
    "Password reset is disabled" : "Đã tắt chức năng đặt lại mật khẩu",
    "%s password reset" : "%s thiết lập lại mật khẩu",
    "Password reset" : "Đặt lại mật khẩu",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Nhấp vào nút sau để đặt lại mật khẩu. Nếu bạn không yêu cầu đặt lại mật khẩu, hãy bỏ qua email này.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Nhấp vào liên kết sau để đặt lại mật khẩu của bạn. Nếu bạn không yêu cầu đặt lại mật khẩu, hãy bỏ qua email này.",
    "Reset your password" : "Đổi mật khẩu",
    "Nextcloud Server" : "Máy chủ vWorkspace",
    "Learn more ↗" : "Để biết thêm↗",
    "Preparing update" : "Đang chuẩn bị cập nhật",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Xin vui lòng sử dụng câu lệnh cập nhật bằng dòng lệnh do cập nhật tự động bị vô hiệu hóa trong file config.php",
    "Turned on maintenance mode" : "Bật chế độ bảo trì",
    "Turned off maintenance mode" : "Tắt chế độ bảo trì",
    "Maintenance mode is kept active" : "Chế độ bảo trì đang được kích hoạt",
    "Updating database schema" : "Đang cập nhật lược đồ cơ sở dữ liệu",
    "Updated database" : "Cơ sở dữ liệu đã được cập nhật",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Đang kiểm tra liệu lược đồ cơ sở dữ liệu đối với %s có thể được cập nhật hay không (việc này có thể mất nhiều thời gian phụ thuộc vào kích cỡ của cơ sở dữ liệu)",
    "Updated \"%1$s\" to %2$s" : "Đã cập nhật \"%1$s\" lên %2$s",
    "Set log level to debug" : "Thiết lập cấp độ ghi nhật ký để gỡ rối",
    "Reset log level" : "Thiế lập lại cấp độ ghi nhật ký hệ thống",
    "Starting code integrity check" : "Bắt đầu mã kiểm tra sự toàn vẹn",
    "Finished code integrity check" : "Kết thúc mã kiểm tra sự toàn vẹn",
    "%s (incompatible)" : "%s (không tương thích)",
    "The following apps have been disabled: %s" : "Những ứng dụng sau đây đã bị tắt: %s",
    "Already up to date" : "Đã được cập nhật bản mới nhất",
    "Error occurred while checking server setup" : "Có lỗi xảy ra khi kiểm tra thiết lập máy chủ",
    "unknown text" : "văn bản không rõ",
    "Hello world!" : "Hello world!",
    "sunny" : "nắng",
    "Hello {name}, the weather is {weather}" : "Xin chào {name}, thời tiết hiện nay {weather}",
    "Hello {name}" : "Xin chào {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Đây là kết quả tìm kiếm của bạn<script>cảnh báo (1)</script></strong>",
    "new" : "mới",
    "_download %n file_::_download %n files_" : ["tải về%ntệp"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "Quá trình cập nhật đang được tiến hành, đóng trang này có thể làm gián đoạn quá trình.",
    "Update to {version}" : "Cập nhật lên {version}",
    "An error occurred." : "Đã xảy ra lỗi.",
    "Please reload the page." : "Vui lòng tải lại trang.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Quá trình cập nhật không thành công. Để biết thêm thông tin chi tiết <a href=\"{url}\">đề nghị xem các bài viết trong diễn đàn </a> để xử lý vấn đề này.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Quá trình cập nhật không thành công. Xin vui lòng báo lại vấn đề gặp phải trong tới  <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Cộng đồng Nextcloud</a>.",
    "More apps" : "Thêm ứng dụng",
    "Log in" : "Đăng nhập",
    "Logging in …" : "Đang đăng nhập",
    "Server side authentication failed!" : "Xác thực phía máy chủ không thành công!",
    "Please contact your administrator." : "Vui lòng liên hệ với quản trị viên.",
    "An internal error occurred." : "Đã xảy ra một lỗi nội bộ.",
    "Please try again or contact your administrator." : "Vui lòng thử lại hoặc liên hệ quản trị của bạn.",
    "Password" : "Mật khẩu",
    "User disabled" : "Vô hiệu hóa sử dụng",
    "Username or email" : "Tên truy cập hoặc email",
    "Reset password" : "Khôi phục mật khẩu",
    "Couldn't send reset email. Please contact your administrator." : "Không thể gửi thư điện tử yêu cầu thiết lập lại. Xin vui lòng liên hệ quản trị hệ thống",
    "Back to login" : "Quay lại trang đăng nhập",
    "New password" : "Mật khẩu mới",
    "I know what I'm doing" : "Tôi biết tôi đang làm gì",
    "Skip" : "Bỏ qua",
    "Forgot password?" : "Quên mật khẩu sao?",
    "Back" : "Quay lại",
    "Reset search" : "Đặt lại tìm kiếm",
    "Load more results" : "Tải thêm kết quả",
    "Search" : "Tìm kiếm",
    "Settings" : "Cài đặt",
    "Could not load your contacts" : "Không thể tải liên hệ của bạn",
    "Search contacts …" : "Tìm liên hệ ...",
    "No contacts found" : "Không tìm thấy liên hệ nào",
    "Show all contacts …" : "Hiển thị tất cả liên hệ…",
    "Loading your contacts …" : "Đang tải liên hệ của bạn ...",
    "Looking for {term} …" : "Đang tìm kiếm {term} ...",
    "No" : "Không",
    "Yes" : "Có",
    "No files in here" : "Không có file nào ở đây",
    "New folder" : "Tạo thư mục",
    "Name" : "Tên",
    "Size" : "Kích cỡ",
    "Modified" : "Thay đổi",
    "\"{name}\" is an invalid file name." : "\"{name}\" không được chấp nhận",
    "File name cannot be empty." : "Tên file không được rỗng",
    "\"/\" is not allowed inside a file name." : "\"/\" ‎không được phép có trong tên tệp.‎",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" không phải là loại tập tin được cho phép",
    "{newName} already exists" : "{newName} đã có",
    "Choose" : "Chọn",
    "Copy" : "Sao chép",
    "Move" : "Chuyển",
    "Error loading file picker template: {error}" : "Lỗi khi tải mẫu tập tin picker: {error}",
    "OK" : "Đồng ý",
    "Error loading message template: {error}" : "Lỗi khi tải mẫu thông điệp: {error}",
    "read-only" : "Chỉ đọc",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} tập tin xung đột"],
    "One file conflict" : "Một tập tin xung đột",
    "New Files" : "File mới",
    "Already existing files" : "Các file đang tồn tại",
    "Which files do you want to keep?" : "Bạn muốn tiếp tục với những tập tin nào?",
    "If you select both versions, the copied file will have a number added to its name." : "Nếu bạn chọn cả hai phiên bản, tập tin được sao chép sẽ được đánh thêm số vào tên của nó.",
    "Cancel" : "Hủy",
    "Continue" : "Tiếp tục",
    "(all selected)" : "(Tất cả các lựa chọn)",
    "({count} selected)" : "({count} được chọn)",
    "Error loading file exists template" : "Lỗi khi tải tập tin mẫu đã tồn tại",
    "Pending" : "Đang chờ được phê duyệt",
    "Copy to {folder}" : "Sao chép tới thư mục {folder}",
    "Move to {folder}" : "Chuyển tới thư mục {folder}",
    "Saving …" : "Đang lưu ...",
    "Authentication required" : "Cần phải được xác thực",
    "This action requires you to confirm your password" : "Để thực hiện hành động này, yêu cầu bạn phải nhập lại mật khẩu",
    "Confirm" : "Xác nhận",
    "Failed to authenticate, try again" : "Không thể xác thực thành công, xin vui lòng thử lại",
    "seconds ago" : "vài giây trước",
    "Connection to server lost" : "Kết nối tới máy chủ bị mất",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Xảy ra lỗi khi tải trang, tải lại trong %n giây"],
    "Very weak password" : "Mật khẩu rất yếu",
    "Weak password" : "Mật khẩu yếu",
    "So-so password" : "Mật khẩu tạm được",
    "Good password" : "Mật khẩu tốt",
    "Strong password" : "Mật khẩu mạnh",
    "No action available" : "Không có hành động nào",
    "Error fetching contact actions" : "Lỗi khi nạp liên hệ",
    "Non-existing tag #{tag}" : "Thẻ không tồn tại # {tag}",
    "Restricted" : "Bị giới hạn",
    "Invisible" : "Vô hình",
    "Delete" : "Xóa",
    "Rename" : "Sửa tên",
    "Collaborative tags" : "Thẻ cộng tác",
    "No tags found" : "Không tìm thấy thẻ",
    "Personal" : "Cá nhân",
    "Users" : "Người dùng",
    "Apps" : "Ứng dụng",
    "Admin" : "Quản trị",
    "Help" : "Giúp đỡ",
    "Access forbidden" : "Truy cập bị cấm",
    "Back to %s" : "Quay lại %s",
    "Page not found" : "Trang không tìm thấy",
    "Error" : "Lỗi",
    "Previous" : "Trước",
    "Internal Server Error" : "Lỗi máy chủ.",
    "The server was unable to complete your request." : "Máy chủ không thể hoàn thành được yêu cầu của bạn",
    "If this happens again, please send the technical details below to the server administrator." : "Nếu điều này tiếp tục xảy ra, xin vui lòng gửi thông tin kỹ thuật chi tiết tới người quản trị hệ thống.",
    "More details can be found in the server log." : "Các chi tiết có thể được tìm thấy trong nhật ký máy chủ.",
    "Technical details" : "Chi tiết kỹ thuật",
    "Remote Address: %s" : "Địa chỉ bên ngoài: %s",
    "Request ID: %s" : "Yêu cầu ID:%s",
    "Type: %s" : "Loại: %s",
    "Code: %s" : "Mã: %s",
    "Message: %s" : "Thông điệp:%s",
    "File: %s" : "Tệp: %s",
    "Line: %s" : "Dòng: %s",
    "Trace" : "Theo dõi",
    "Security warning" : "Cảnh báo bảo mật",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Thư mục và file dữ liệu của bạn có thể được truy cập từ internet bởi vì file .htaccess không hoạt động",
    "Create an <strong>admin account</strong>" : "Tạo một <strong>tài khoản quản trị</strong>",
    "Username" : "Tên đăng nhập",
    "Show password" : "Hiện mật khẩu",
    "Storage & database" : "Lưu trữ & cơ sở dữ liệu",
    "Data folder" : "Thư mục dữ liệu",
    "Configure the database" : "Cấu hình cơ sở dữ liệu",
    "Only %s is available." : "Chỉ %s khả dụng.",
    "Install and activate additional PHP modules to choose other database types." : "Cài đặt và kích hoạt các mô-đun PHP bổ sung để chọn các loại cơ sở dữ liệu khác.",
    "For more details check out the documentation." : "Để biết thêm chi tiết, hãy kiểm tra tài liệu.",
    "Database user" : "Người dùng cơ sở dữ liệu",
    "Database password" : "Mật khẩu cơ sở dữ liệu",
    "Database name" : "Tên cơ sở dữ liệu",
    "Database tablespace" : "Cơ sở dữ liệu tablespace",
    "Database host" : "Database host",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Vui lòng xác định số cổng cùng với tên máy chủ lưu trữ (ví dụ: localhost: 5432).",
    "Performance warning" : "Cảnh báo hiệu suất",
    "Install" : "Cài đặt",
    "Need help?" : "Cần hỗ trợ ?",
    "See the documentation" : "Xem tài liệu",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Ứng dụng này yêu cầu JavaScript để hoạt động chính xác. Vui lòng {linkstart} bật JavaScript {linkend} và tải lại trang.",
    "Contacts" : "Liên hệ",
    "Contacts menu" : "Trình đơn liên hệ",
    "Confirm your password" : "Xác nhận mật khẩu của bạn",
    "Connect to your account" : "Kết nối tài khoản của bạn",
    "App token" : "Dấu hiệu ứng dụng",
    "Grant access" : "Cấp quyền truy cập",
    "Account access" : "Truy cập tài khoản",
    "This share is password-protected" : "Chia sẽ này được bảo vệ bởi mật khẩu",
    "Email address" : "Địa chỉ thư điện tử",
    "Go to %s" : "Đi tới %s",
    "Two-factor authentication" : "Xác thực 2 bước",
    "Use backup code" : "Sử dụng mã dự phòng",
    "Error while validating your second factor" : "Lỗi khi xác thực 2 bước",
    "Access through untrusted domain" : "Truy nhập thông qua tên miền không đáng tin",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Xin vui lòng liên hệ với quản trị hệ thống của bạn. Nếu ban là người quản trị hệ thống, sửa phần thiết lập \"trusted_domains\" trong file config/config.php giống như trong ví dụ tại file config.sample.php.",
    "App update required" : "Ứng dụng yêu cầu cập nhật",
    "These incompatible apps will be disabled:" : "Những ứng dụng không tương thích sẽ bị tắt:",
    "The theme %s has been disabled." : "Giao diện %s đã bị tắt.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Bạn cần phải bảo đảm rằng cơ sở dữ liệu, thư mục chứa file cấu hình hệ thống và thư mục chứa dữ liệu người dùng phải được sao lưu trước khi thực hiện.",
    "Start update" : "Bắt đầu cập nhật",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Để tránh thời gian quá hạn với các cài đặt lớn hơn, bạn có thể thực hiện chạy lệnh sau từ thư mục cài đặt:",
    "Detailed logs" : "Nhật ký chi tiết",
    "Update needed" : "Cần phải cập nhật",
    "Please use the command line updater because you have a big instance with more than 50 users." : "Xin vui lòng sử dụng lệnh cập nhật bằng dòng lệnh bởi vì bạn có một bản cài đặt lớn có hơn 50 người dùng.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Trợ giúp, xem <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Tôi biết rằng nếu tôi tiếp tục thực hiện cập nhập qua giao diện Web có rủi ro, mà yêu cầu đó chạy trong một khoảng thời gian bị quá hạn và có thể gây mất dữ liệu, nếu tôi có một bản sao và tôi biết cách khôi phục bản cài đặt đã sao lưu trong trường hợp bị lỗi khi cập nhật.",
    "Upgrade via web on my own risk" : "Nâng cấp qua web",
    "This %s instance is currently in maintenance mode, which may take a while." : "Bản cài đặt%s hiện tại đang trong chế độ \"bảo trì\", do vậy có thể bạn cần phải đợi thêm chút ít thời gian.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Liên hệ với người quản trị nếu lỗi này vẫn tồn tại hoặc xuất hiện bất ngờ.",
    "[%d / %d]: Checking table %s" : "[%d / %d]: đang kiểm tra bảng được %s",
    "restricted" : "hạn chế",
    "invisible" : "không thể nhìn thấy.",
    "File not found" : "Không tìm thấy tệp tin",
    "More" : "hơn",
    "More apps menu" : "Nhiều trình đơn ứng dụng hơn",
    "Settings menu" : "Trình đơn thiết lập",
    "The password is wrong. Try again." : "Sai mật khẩu. Hãy thử lại."
},
"nplurals=1; plural=0;");
